@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/pkg/bin/python3.12",
 
         # Package versions
-        contourpy_version="1.3.2",
-        meson_version="1.8.2",
+        contourpy_version="1.3.3",
+        meson_version="1.9.0",
         mesonpy_version="0.18.0",
-        pybind11_version="2.13.6",
+        pybind11_version="3.0.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work.aarch64eb/contourpy-1.3.2/.mesonpy-vfobt913/lib/contourpy/util",
-        source_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work.aarch64eb/contourpy-1.3.2/lib/contourpy/util",
+        build_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work/contourpy-1.3.3/.mesonpy-rpbjn92q/lib/contourpy/util",
+        source_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work/contourpy-1.3.3/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/tmp/pkgbuild/graphics/py-contourpy/work.aarch64eb/contourpy-1.3.2/.mesonpy-vfobt913/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/tmp/pkgbuild/graphics/py-contourpy/work/contourpy-1.3.3/.mesonpy-rpbjn92q/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -47,14 +47,14 @@ def build_config() -> dict[str, str]:
         compile_command="c++",
 
         # Host machine
-        host_cpu="aarch64",
-        host_cpu_family="aarch64",
+        host_cpu="powerpc",
+        host_cpu_family="ppc",
         host_cpu_endian="big",
         host_cpu_system="netbsd",
 
         # Build machine, same as host machine if not a cross_build
-        build_cpu="aarch64",
-        build_cpu_family="aarch64",
+        build_cpu="powerpc",
+        build_cpu_family="ppc",
         build_cpu_endian="big",
         build_cpu_system="netbsd",
     )
